Installation
************

This section shows how you can install this BalderHub package.

Install python
==============

For this python in the version ``3.9`` or higher is required. You can get the latest version of python at
`https://www.python.org/downloads/ <https://www.python.org/downloads/>`_ or install it with your packet management
system of your operating system.

Install balder
==============

You can easily install balder with the following command.

.. code-block::

    python -m pip install baldertest

Install balderhub-ble
=====================

You can install this package with the following command:

.. code-block::

    python -m pip install balderhub-ble
